@@ -1,18 +1,16 @@
 from typing import Optional
 
 import docker
-from cachetools import TTLCache, cached
 
 from .config import Config
 from .data_model import *
 from .exceptions import *
 from .services import *
-from .version import VERSION
 
 __all__ = ["Beaker"]
 
 
-_UPGRADE_WARNING_ISSUED = False
+_LATEST_VERSION_CHECKED = False
 
 
 class Beaker:
@@ -20,6 +18,8 @@ class Beaker:
     A client for interacting with `Beaker <https://beaker.org>`_.
 
     :param config: The Beaker :class:`Config`.
+    :param check_for_upgrades: Automatically check that beaker-py is up-to-date. You'll see
+            a warning if it isn't.
 
     The easiest way to initialize a Beaker client is with :meth:`.from_env()`:
 
@@ -38,7 +38,7 @@ class Beaker:
 
     def __init__(self, config: Config, check_for_upgrades: bool = True):
         # See if there's a newer version, and if so, suggest that the user upgrades.
-        if check_for_upgrades and not _UPGRADE_WARNING_ISSUED:
+        if check_for_upgrades:
             self._check_for_upgrades()
 
         self._config = config
@@ -55,6 +55,7 @@ class Beaker:
         self._job = JobClient(self)
         self._experiment = ExperimentClient(self)
         self._secret = SecretClient(self)
+        self._group = GroupClient(self)
 
         # Ensure default workspace exists.
         if self._config.default_workspace is not None:
@@ -68,19 +69,24 @@ class Beaker:
             f"Beaker("
             f"user='{self.account.name}', "
             f"default_workspace='{self.config.default_workspace}', "
-            f"default_org='{self.config.default_org}'"
+            f"default_org='{self.config.default_org}', "
+            f"agent_address='{self.config.agent_address}'"
             f")"
         )
 
     @staticmethod
-    @cached(cache=TTLCache(maxsize=10, ttl=5 * 60))
     def _check_for_upgrades():
+        global _LATEST_VERSION_CHECKED
+
+        if _LATEST_VERSION_CHECKED:
+            return
+
         import warnings
 
         import packaging.version
         import requests
 
-        global _UPGRADE_WARNING_ISSUED
+        from .version import VERSION
 
         try:
             response = requests.get(
@@ -88,25 +94,37 @@ class Beaker:
             )
             if response.ok:
                 latest_version = packaging.version.parse(response.json()["tag_name"])
+                _LATEST_VERSION_CHECKED = True
                 if latest_version > packaging.version.parse(VERSION):
                     warnings.warn(
                         f"You're using beaker-py v{VERSION}, "
-                        f"but a newer version (v{latest_version}) is available. "
-                        f"Please upgrade with `pip install --upgrade beaker-py`.",
+                        f"but a newer version (v{latest_version}) is available.\n\n"
+                        f"Please upgrade with `pip install --upgrade beaker-py`.\n\n"
+                        f"You can find the release notes for v{latest_version} at "
+                        f"https://github.com/allenai/beaker-py/releases/tag/v{latest_version}\n",
                         UserWarning,
                     )
-                    _UPGRADE_WARNING_ISSUED = True
         except (requests.exceptions.Timeout, requests.exceptions.ConnectionError):
             pass
 
     @classmethod
-    def from_env(cls, **overrides) -> "Beaker":
+    def from_env(cls, check_for_upgrades: bool = True, **overrides) -> "Beaker":
         """
         Initialize client from a config file and/or environment variables.
 
+        :param check_for_upgrades: Automatically check that beaker-py is up-to-date. You'll see
+            a warning if it isn't.
         :param overrides: Fields in the :class:`Config` to override.
+
+        .. note::
+            This will use the same config file that the `Beaker command-line client
+            <https://github.com/allenai/beaker/>`_
+            creates and uses, which is usually located at ``$HOME/.beaker/config.yml``.
+
+            If you haven't configured the command-line client, then you can alternately just
+            set the environment variable ``BEAKER_TOKEN`` to your Beaker `user token <https://beaker.org/user>`_.
         """
-        return cls(Config.from_env(**overrides))
+        return cls(Config.from_env(**overrides), check_for_upgrades=check_for_upgrades)
 
     @property
     def config(self) -> Config:
@@ -177,7 +195,7 @@ class Beaker:
 
         :examples:
 
-        >>> beaker.cluster.get(beaker_cluster_name).autoscale
+        >>> beaker.cluster.get(beaker_cloud_cluster_name).autoscale
         True
 
         .. tip::
@@ -293,6 +311,22 @@ class Beaker:
         """
         return self._secret
 
+    @property
+    def group(self) -> GroupClient:
+        """
+        Manage groups.
+
+        :examples:
+
+        >>> group = beaker.group.create(group_name)
+
+        .. tip::
+            See the `Groups Overview <overview.html#groups>`_ for a walk-through of the
+            main methods, or check out the `Group API Docs <#group>`_
+            to see all of the available methods.
+        """
+        return self._group
+
     @property
     def docker(self) -> docker.DockerClient:
         if self._docker is None:
