@@ -139,3 +139,29 @@ class DatasetReadError(BeakerError):
 
 class SecretNotFound(BeakerError):
     pass
+
+
+class GroupConflict(BeakerError):
+    """
+    Raised when attempting to create/rename a group if a group by that name already exists.
+    """
+
+
+class GroupNotFound(BeakerError):
+    pass
+
+
+class DuplicateJobError(BeakerError):
+    """
+    Raised when duplicate jobs are passed into a method that expects unique jobs.
+    """
+
+
+class DuplicateExperimentError(BeakerError):
+    """
+    Raised when duplicate experiments are passed into a method that expects unique experiments.
+    """
+
+
+class TaskNotFound(BeakerError):
+    pass
