@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Dict, List, Union
 
 from ..data_model import *
 from ..exceptions import *
@@ -88,7 +88,7 @@ class ClusterClient(ServiceClient):
                     "name": cluster_name,
                     "capacity": max_size,
                     "preemptible": preemptible,
-                    "spec": NodeSpec(
+                    "spec": NodeResources(
                         cpu_count=cpus, gpu_count=gpus, gpu_type=gpu_type, memory=memory
                     ).to_json(),
                 },
@@ -113,7 +113,7 @@ class ClusterClient(ServiceClient):
                 f"clusters/{cluster_name}",
                 method="PATCH",
                 data={"capacity": max_size},
-                exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster_name))},
+                exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster))},
             ).json()
         )
 
@@ -131,7 +131,7 @@ class ClusterClient(ServiceClient):
         self.request(
             f"clusters/{cluster_name}",
             method="DELETE",
-            exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster_name))},
+            exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster))},
         )
 
     def list(self, org: Optional[Union[str, Organization]] = None) -> List[Cluster]:
@@ -173,11 +173,11 @@ class ClusterClient(ServiceClient):
             for d in self.request(
                 f"clusters/{cluster_name}/nodes",
                 method="GET",
-                exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster_name))},
+                exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster))},
             ).json()["data"]
         ]
 
-    def utilization(self, cluster: Union[str, Cluster]) -> List[NodeUtilization]:
+    def utilization(self, cluster: Union[str, Cluster]) -> ClusterUtilization:
         """
         Get current utilization stats for each node in a cluster.
 
@@ -189,46 +189,79 @@ class ClusterClient(ServiceClient):
         """
         cluster: Cluster = self.resolve_cluster(cluster)
         nodes = self.nodes(cluster)
-        out: List[NodeUtilization] = []
-        for node in nodes:
-            gpus_used = 0
-            cpus_used = 0.0
-            for job in self.beaker.job.list(node=node, finalized=False):
+
+        running_jobs = 0
+        queued_jobs = 0
+        node_to_util: Dict[str, Dict[str, Union[int, float]]] = {
+            node.id: {"running_jobs": 0, "gpus_used": 0, "cpus_used": 0.0} for node in nodes
+        }
+
+        for job in self.beaker.job.list(cluster=cluster, finalized=False):
+            if job.status.current == CurrentJobStatus.running:
+                running_jobs += 1
+            elif job.status.current == CurrentJobStatus.created:
+                queued_jobs += 1
+
+            if job.node is not None:
+                if job.node not in node_to_util:
+                    continue  # unlikely
+
+                node_util = node_to_util[job.node]
+                node_util["running_jobs"] += 1
                 if job.requests is not None:
                     if job.requests.gpu_count is not None:
-                        gpus_used += job.requests.gpu_count
+                        node_util["gpus_used"] += job.requests.gpu_count
                     if job.requests.cpu_count is not None:
-                        cpus_used += job.requests.cpu_count
-            used = NodeSpecUtil(
-                gpu_count=None if node.limits.gpu_count is None else gpus_used,
-                cpu_count=None if node.limits.cpu_count is None else cpus_used,
-            )
-            free = NodeSpecUtil(
-                gpu_count=None
-                if node.limits.gpu_count is None
-                else node.limits.gpu_count - gpus_used,
-                cpu_count=None
-                if node.limits.cpu_count is None
-                else node.limits.cpu_count - cpus_used,
-            )
-            out.append(
+                        node_util["cpus_used"] += job.requests.cpu_count
+
+        return ClusterUtilization(
+            id=cluster.id,
+            running_jobs=running_jobs,
+            queued_jobs=queued_jobs,
+            nodes=[
                 NodeUtilization(
                     id=node.id,
                     hostname=node.hostname,
                     limits=node.limits,
-                    used=used,
-                    free=free,
+                    running_jobs=node_to_util[node.id]["running_jobs"],
+                    used=NodeResources(
+                        gpu_count=None
+                        if node.limits.gpu_count is None
+                        else min(node.limits.gpu_count, node_to_util[node.id]["gpus_used"]),
+                        cpu_count=None
+                        if node.limits.cpu_count is None
+                        else min(node.limits.cpu_count, node_to_util[node.id]["cpus_used"]),
+                        gpu_type=node.limits.gpu_type,
+                    ),
+                    free=NodeResources(
+                        gpu_count=None
+                        if node.limits.gpu_count is None
+                        else max(0, node.limits.gpu_count - node_to_util[node.id]["gpus_used"]),
+                        cpu_count=None
+                        if node.limits.cpu_count is None
+                        else max(0, node.limits.cpu_count - node_to_util[node.id]["cpus_used"]),
+                        gpu_type=node.limits.gpu_type,
+                    ),
                 )
-            )
-        return out
+                for node in nodes
+            ],
+        )
 
     def filter_available(
         self, resources: TaskResources, *clusters: Union[str, Cluster]
-    ) -> List[Cluster]:
+    ) -> List[ClusterUtilization]:
         """
-        Filter clusters with enough free resources to run a job with the requested resources.
+        Filter out clusters that don't have enough available resources, returning
+        a list of :class:`ClusterUtilization <beaker.data_model.cluster.ClusterUtilization>` for each
+        cluster that has sufficient resources.
 
-        :param resources: The requested task resources.
+        This can be used, for example, to automatically find an on-premise cluster with enough
+        free resources to run a particular task.
+
+        .. caution::
+            This method is experimental and may change or be removed in future releases.
+
+        :param resources: The requested resources.
         :param clusters: Clusters to inspect and filter.
 
         :raises ClusterNotFound: If one of the clusters doesn't exist.
@@ -236,37 +269,38 @@ class ClusterClient(ServiceClient):
         :raises HTTPError: Any other HTTP exception that can occur.
         """
 
-        def is_compat(node_spec: Union[NodeSpec, NodeShape, NodeSpecUtil]) -> bool:
+        def is_compat(node_shape: NodeResources) -> bool:
             if resources.gpu_count and (
-                node_spec.gpu_count is None or node_spec.gpu_count < resources.gpu_count
+                node_shape.gpu_count is None or node_shape.gpu_count < resources.gpu_count
             ):
                 return False
             if resources.cpu_count and (
-                node_spec.cpu_count is None or node_spec.cpu_count < resources.cpu_count
+                node_shape.cpu_count is None or node_shape.cpu_count < resources.cpu_count
             ):
                 return False
             # TODO: check memory too
             return True
 
-        available: List[Cluster] = []
+        available: List[ClusterUtilization] = []
         for cluster_ in clusters:
             cluster: Cluster = self.resolve_cluster(cluster_)
 
             if cluster.node_shape is not None and not is_compat(cluster.node_shape):
                 continue
 
-            node_utilization = self.utilization(cluster)
-            if cluster.autoscale and len(node_utilization) < cluster.capacity:
-                available.append(cluster)
+            cluster_utilization = self.utilization(cluster)
+            if cluster.autoscale and len(cluster_utilization.nodes) < cluster.capacity:
+                available.append(cluster_utilization)
             else:
-                for node_util in node_utilization:
+                for node_util in cluster_utilization.nodes:
                     if is_compat(node_util.free):
-                        available.append(cluster)
+                        available.append(cluster_utilization)
                         break
 
-        return available
+        return sorted(available, key=lambda util: (util.queued_jobs, util.running_jobs))
 
-    def _not_found_err_msg(self, cluster: str) -> str:
+    def _not_found_err_msg(self, cluster: Union[str, Cluster]) -> str:
+        cluster = cluster if isinstance(cluster, str) else cluster.id
         return (
             f"'{cluster}': Make sure you're using a valid ID or *full* name of the cluster "
             f"(with the organization prefix, e.g. 'org/cluster_name')"
