@@ -1,24 +1,16 @@
 import os
 from datetime import datetime
 from pathlib import Path
-from typing import Deque, Dict, Generator, List, Optional, Tuple, Union
-
-from rich.progress import (
-    BarColumn,
-    Progress,
-    ProgressColumn,
-    SpinnerColumn,
-    TaskID,
-    TimeElapsedColumn,
-    TimeRemainingColumn,
-)
+from typing import TYPE_CHECKING, Deque, Dict, Generator, Optional, Tuple, Union
 
 from ..aliases import PathOrStr
 from ..data_model import *
 from ..exceptions import *
-from ..util import BufferedReaderWithProgress, DownloadUploadColumn
 from .service_client import ServiceClient
 
+if TYPE_CHECKING:
+    from rich.progress import Progress, TaskID
+
 
 class DatasetClient(ServiceClient):
     """
@@ -97,7 +89,7 @@ class DatasetClient(ServiceClient):
             the contents of one of the directory's files changes while creating the dataset.
         :raises FileNotFoundError: If a source doesn't exist.
         :raises WorkspaceNotSet: If neither ``workspace`` nor
-            :data:`Beaker.config.defeault_workspace <beaker.Config.default_workspace>` are set.
+            :data:`Beaker.config.default_workspace <beaker.Config.default_workspace>` are set.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
         :raises HTTPError: Any other HTTP exception that can occur.
         """
@@ -155,7 +147,7 @@ class DatasetClient(ServiceClient):
                 f"datasets/{self.url_quote(dataset_id)}",
                 method="PATCH",
                 data={"commit": True},
-                exceptions_for_status={404: DatasetNotFound(self._not_found_err_msg(dataset_id))},
+                exceptions_for_status={404: DatasetNotFound(self._not_found_err_msg(dataset))},
             ).json()
         )
 
@@ -177,7 +169,7 @@ class DatasetClient(ServiceClient):
         :param quiet: If ``True``, progress won't be displayed.
 
         :raises DatasetNotFound: If the dataset can't be found.
-        :raises DatasetReadError: If the :data:`~beaker.data_model.Dataset.storage` hasn't been set.
+        :raises DatasetReadError: If the :data:`~beaker.data_model.dataset.Dataset.storage` hasn't been set.
         :raises FileExistsError: If ``force=False`` and an existing local file clashes with a file
             in the Beaker dataset.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
@@ -204,26 +196,18 @@ class DatasetClient(ServiceClient):
 
         total_bytes_to_download: Optional[int] = None
         total_downloaded: int = 0
-        progress_columns: List[Union[str, ProgressColumn]]
+        from ..progress import (
+            get_sized_dataset_fetch_progress,
+            get_unsized_dataset_fetch_progress,
+        )
+
         if storage_info.size is not None and storage_info.size.final:
             total_bytes_to_download = storage_info.size.bytes
-            progress_columns = [
-                "[progress.description]{task.description}",
-                BarColumn(),
-                "[progress.percentage]{task.percentage:>3.0f}%",
-                TimeElapsedColumn(),
-                TimeRemainingColumn(),
-                DownloadUploadColumn(),
-            ]
+            progress = get_sized_dataset_fetch_progress(quiet)
         else:
-            progress_columns = [
-                "[progress.description]{task.description}",
-                SpinnerColumn(),
-                TimeElapsedColumn(),
-                DownloadUploadColumn(),
-            ]
+            progress = get_unsized_dataset_fetch_progress(quiet)
 
-        with Progress(*progress_columns, disable=quiet) as progress:
+        with progress:
             bytes_task = progress.add_task("Downloading dataset")
             if total_bytes_to_download is not None:
                 progress.update(bytes_task, total=total_bytes_to_download)
@@ -274,7 +258,7 @@ class DatasetClient(ServiceClient):
             Errors can be expected for very large files.
 
         :raises DatasetNotFound: If the dataset can't be found.
-        :raises DatasetReadError: If the :data:`~beaker.data_model.Dataset.storage` hasn't been set.
+        :raises DatasetReadError: If the :data:`~beaker.data_model.dataset.Dataset.storage` hasn't been set.
         :raises FileNotFoundError: If the file doesn't exist in the dataset.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
         :raises HTTPError: Any other HTTP exception that can occur.
@@ -317,7 +301,7 @@ class DatasetClient(ServiceClient):
         self.request(
             f"datasets/{self.url_quote(dataset_id)}",
             method="DELETE",
-            exceptions_for_status={404: DatasetNotFound(self._not_found_err_msg(dataset_id))},
+            exceptions_for_status={404: DatasetNotFound(self._not_found_err_msg(dataset))},
         )
 
     def sync(
@@ -350,15 +334,9 @@ class DatasetClient(ServiceClient):
         if dataset.committed is not None:
             raise DatasetWriteError(dataset.id)
 
-        with Progress(
-            "[progress.description]{task.description}",
-            BarColumn(),
-            "[progress.percentage]{task.percentage:>3.0f}%",
-            TimeElapsedColumn(),
-            TimeRemainingColumn(),
-            DownloadUploadColumn(),
-            disable=quiet,
-        ) as progress:
+        from ..progress import get_dataset_sync_progress
+
+        with get_dataset_sync_progress(quiet) as progress:
             bytes_task = progress.add_task("Uploading dataset")
             total_bytes = 0
             # map source path to (target_path, size)
@@ -427,7 +405,7 @@ class DatasetClient(ServiceClient):
         :param dataset: The dataset ID, name, or object.
 
         :raises DatasetNotFound: If the dataset can't be found.
-        :raises DatasetReadError: If the :data:`~beaker.data_model.Dataset.storage` hasn't been set.
+        :raises DatasetReadError: If the :data:`~beaker.data_model.dataset.Dataset.storage` hasn't been set.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
         :raises HTTPError: Any other HTTP exception that can occur.
         """
@@ -483,7 +461,8 @@ class DatasetClient(ServiceClient):
             ).json()
         )
 
-    def _not_found_err_msg(self, dataset: str) -> str:
+    def _not_found_err_msg(self, dataset: Union[str, Dataset]) -> str:
+        dataset = dataset if isinstance(dataset, str) else dataset.id
         return (
             f"'{dataset}': Make sure you're using a valid Beaker dataset ID or the "
             f"*full* name of the dataset (with the account prefix, e.g. 'username/dataset_name')"
@@ -495,8 +474,8 @@ class DatasetClient(ServiceClient):
         size: int,
         source: PathOrStr,
         target: PathOrStr,
-        progress: Progress,
-        task_id: TaskID,
+        progress: "Progress",
+        task_id: "TaskID",
         ignore_errors: bool = False,
     ) -> int:
         source: Path = Path(source)
@@ -505,6 +484,8 @@ class DatasetClient(ServiceClient):
             return 0
 
         with source.open("rb") as source_file:
+            from ..progress import BufferedReaderWithProgress
+
             source_file_wrapper = BufferedReaderWithProgress(source_file, progress, task_id)
             body: Optional[BufferedReaderWithProgress] = source_file_wrapper
             digest: Optional[bytes] = None
@@ -554,6 +535,10 @@ class DatasetClient(ServiceClient):
                 base_url=dataset.storage.address,
                 headers=None if not digest else {self.HEADER_DIGEST: self._encode_digest(digest)},
                 stream=body is not None,
+                exceptions_for_status={
+                    403: DatasetWriteError(dataset.id),
+                    404: DatasetNotFound(self._not_found_err_msg(dataset.id)),
+                },
             )
 
             return source_file_wrapper.total_read
@@ -637,8 +622,8 @@ class DatasetClient(ServiceClient):
         storage: DatasetStorage,
         file_info: FileInfo,
         target_path: Path,
-        progress: Progress,
-        task_id: TaskID,
+        progress: "Progress",
+        task_id: "TaskID",
     ) -> int:
         import tempfile
 
