@@ -92,15 +92,9 @@ class ServiceClient:
         else:
             org, name = cluster_name.split("/", 1)
             self.validate_beaker_name(name)
-            self.beaker.organization.get(org)
+            self.resolve_org(org)
             return cluster_name
 
-    def resolve_cluster(self, cluster: Union[str, Cluster]) -> Cluster:
-        if isinstance(cluster, Cluster):
-            return cluster
-        else:
-            return self.beaker.cluster.get(cluster)
-
     def resolve_workspace_name(self, workspace_name: str) -> str:
         """
         Takes the name of a workspace (possibly non-existent) and returns a valid full name.
@@ -118,9 +112,15 @@ class ServiceClient:
         else:
             org, name = workspace_name.split("/", 1)
             self.validate_beaker_name(name)
-            self.beaker.organization.get(org)
+            self.resolve_org(org)
             return workspace_name
 
+    def resolve_cluster(self, cluster: Union[str, Cluster]) -> Cluster:
+        if isinstance(cluster, Cluster):
+            return cluster
+        else:
+            return self.beaker.cluster.get(cluster)
+
     def resolve_workspace(
         self,
         workspace: Optional[Union[str, Workspace]],
@@ -155,6 +155,12 @@ class ServiceClient:
         else:
             return self.beaker.image.get(image)
 
+    def resolve_group(self, group: Union[str, Group]) -> Group:
+        if isinstance(group, Group):
+            return group
+        else:
+            return self.beaker.group.get(group)
+
     def resolve_org(self, org: Optional[Union[str, Organization]]) -> Organization:
         if isinstance(org, Organization):
             return org
